@@ -62,12 +62,12 @@ public:
   const QString& preamble() const { return m_preamble; }
   void setPreamble(const QString& preamble) { m_preamble = preamble; }
   const StringMap& macroList() const { return m_macros; }
-  void setMacroList(StringMap map) { m_macros = map; }
+  void setMacroList(const StringMap& map) { m_macros = map; }
   void addMacro(const QString& key, const QString& value) { m_macros.insert(key, value); }
 
   virtual QString prepareText(const QString& text) const Q_DECL_OVERRIDE;
   virtual int sameEntry(Data::EntryPtr entry1, Data::EntryPtr entry2) const Q_DECL_OVERRIDE;
-  
+
   EntryList duplicateBibtexKeys() const;
 
   static FieldList defaultFields();
