@@ -96,8 +96,8 @@ void BibsonomyFetcher::search() {
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
-  connect(m_job, SIGNAL(result(KJob*)),
-          SLOT(slotComplete(KJob*)));
+  connect(m_job.data(), &KJob::result,
+          this, &BibsonomyFetcher::slotComplete);
 }
 
 void BibsonomyFetcher::stop() {
