@@ -71,6 +71,10 @@ public:
    */
   virtual bool canSearch(FetchKey key) const = 0;
   virtual bool canUpdate() const;
+  /**
+   * Returns true if the fetcher requires a user agent to be sent
+   */
+  virtual bool needsUserAgent() const { return false; }
 
   /**
    * Returns the type of the data source.
@@ -162,6 +166,7 @@ private:
   QString m_configGroup;
   QStringList m_fields;
   QString m_uuid;
+  QHash<uint, Data::EntryPtr> m_entries;
 };
 
   } // end namespace
