@@ -105,7 +105,7 @@ void FilmasterFetcher::search() {
 
   QPointer<KIO::StoredTransferJob> job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(job, GUI::Proxy::widget());
-  connect(job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
+  connect(job.data(), &KJob::result, this, &FilmasterFetcher::slotComplete);
 }
 
 void FilmasterFetcher::stop() {
