@@ -97,7 +97,7 @@ void MRLookupFetcher::search() {
 //  myDebug() << u;
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
-  connect(m_job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
+  connect(m_job.data(), &KJob::result, this, &MRLookupFetcher::slotComplete);
 }
 
 void MRLookupFetcher::stop() {
