@@ -74,6 +74,10 @@ QString MusicBrainzFetcher::source() const {
   return m_name.isEmpty() ? defaultName() : m_name;
 }
 
+bool MusicBrainzFetcher::canSearch(FetchKey k) const {
+  return k == Title || k == Person || k == Keyword || k == UPC;
+}
+
 bool MusicBrainzFetcher::canFetch(int type) const {
   return type == Data::Collection::Album;
 }
@@ -112,6 +116,10 @@ void MusicBrainzFetcher::doSearch() {
       queryString = QStringLiteral("artist:\"%1\"").arg(request().value);
       break;
 
+    case UPC:
+      queryString = QStringLiteral("barcode:\"%1\"").arg(request().value);
+      break;
+
     case Keyword:
       queryString = QStringLiteral("artist:\"") + request().value + QStringLiteral("\" OR ") +
                     QStringLiteral("release:\"") + request().value + QStringLiteral("\" OR ")  +
@@ -331,6 +339,11 @@ void MusicBrainzFetcher::initXSLTHandler() {
 }
 
 Tellico::Fetch::FetchRequest MusicBrainzFetcher::updateRequest(Data::EntryPtr entry_) {
+  const QString barcode = entry_->field(QStringLiteral("barcode"));
+  if(!barcode.isEmpty()) {
+    return FetchRequest(UPC, barcode);
+  }
+
   const QString title = entry_->field(QStringLiteral("title"));
   const QString artist = entry_->field(QStringLiteral("artist"));
   if(artist.isEmpty() && !title.isEmpty()) {
