@@ -105,7 +105,7 @@ private:
   QString m_apiKey;
   QString m_imageBase;
 
-  QHash<int, Data::EntryPtr> m_entries;
+  QHash<uint, Data::EntryPtr> m_entries;
   QPointer<KIO::StoredTransferJob> m_job;
 };
 
