@@ -30,6 +30,10 @@
 #include <QByteArray>
 #include <QPixmap>
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
+using qsizetype = QIntegerForSizeof<std::size_t>::Signed;
+#endif
+
 namespace Tellico {
   class ImageFactory;
   class ImageDirectory;
