@@ -40,6 +40,7 @@ class KToolBar;
 class QAction;
 class KSelectAction;
 class KToggleAction;
+class KDualAction;
 class KRecentFilesAction;
 class KActionMenu;
 
@@ -397,7 +398,7 @@ private Q_SLOTS:
    * Update the filter to match any field with text. If a non-word character appears, the
    * text is interpreted as a regexp.
    */
-  void slotUpdateFilter();
+  void slotCheckFilterQueue();
   void slotUpdateFilter(Tellico::FilterPtr filter);
   /**
    * Updates the collection toolbar.
@@ -480,6 +481,7 @@ private:
   QAction* m_checkInEntry;
   QAction* m_checkOutEntry;
   KToggleAction* m_toggleEntryEditor;
+  KDualAction* m_lockLayout;
 
   KSelectAction* m_entryGrouping;
   GUI::LineEdit* m_quickFilter;
