@@ -139,7 +139,7 @@ QVariant FilterModel::data(const QModelIndex& index_, int role_) const {
     case RowCountRole:
       return rowCount(index_);
     case EntryPtrRole:
-      return qVariantFromValue(entry(index_));
+      return QVariant::fromValue(entry(index_));
   }
 
   return QVariant();
