@@ -37,6 +37,7 @@
 #include "../entry.h"
 #include "../images/imagefactory.h"
 
+#include <KSharedConfig>
 #include <KConfigGroup>
 
 #include <QTest>
@@ -434,6 +435,7 @@ void AmazonFetcherTest::testPayload() {
 \"PartnerType\":\"Associates\",\
 \"Resources\":[\"ItemInfo.Title\",\"ItemInfo.ContentInfo\",\"ItemInfo.ByLineInfo\",\"ItemInfo.TechnicalInfo\",\"ItemInfo.ExternalIds\",\"ItemInfo.ManufactureInfo\",\"Images.Primary.Medium\"],\
 \"SearchIndex\":\"Books\",\
+\"Service\":\"ProductAdvertisingAPIv1\",\
 \"SortBy\":\"Relevance\"\
 }");
   QCOMPARE(payload.right(100), res1.right(100));
@@ -450,7 +452,6 @@ void AmazonFetcherTest::testError() {
   f->m_site = Tellico::Fetch::AmazonFetcher::US;
   f->m_accessKey = QStringLiteral("test");
   f->m_secretKey = QStringLiteral("test");
-  f->m_testResultsFile = QFINDTESTDATA("data/amazon-paapi-error1.json");
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
   QVERIFY(!logger->errorList.isEmpty());
