@@ -75,7 +75,7 @@ void DarkHorseFetcherTest::testComic() {
 
   QCOMPARE(entry->field(QSL("title")), QSL("Axe Cop: Bad Guy Earth #1"));
   QCOMPARE(entry->field(QSL("pub_year")), QSL("2011"));
-  QCOMPARE(entry->field(QSL("genre")), QSL("Humor"));
+  QCOMPARE(entry->field(QSL("genre")), QSL("Humor; Kids"));
   QCOMPARE(entry->field(QSL("pages")), QSL("32"));
   QCOMPARE(entry->field(QSL("publisher")), QSL("Dark Horse Comics"));
   QCOMPARE(entry->field(QSL("writer")), QSL("Malachai Nicolle"));
