@@ -36,15 +36,15 @@ QTEST_APPLESS_MAIN( LccTest )
 void LccTest::testSorting() {
   Tellico::LCCComparison comp;
 
-  QString lcc1 = QLatin1String("B17.A4 1990");
-  QString lcc2 = QLatin1String("B17.G3 1964");
-  QString lcc3 = QLatin1String("B17.6.B64 Z59");
-  QString lcc4 = QLatin1String("B17.6.B8 G37");
-  QString lcc5 = QLatin1String("BR123.H4");
-  QString lcc6 = QLatin1String("BR123.H56");
-  QString lcc7 = QLatin1String("BR123.H56 1935");
-  QString lcc8 = QLatin1String("BR123.H56 B5");
-  QString lcc9 = QLatin1String("BR123.H8 v.1");
+  QString lcc1 = QStringLiteral("B17.A4 1990");
+  QString lcc2 = QStringLiteral("B17.G3 1964");
+  QString lcc3 = QStringLiteral("B17.6.B64 Z59");
+  QString lcc4 = QStringLiteral("B17.6.B8 G37");
+  QString lcc5 = QStringLiteral("BR123.H4");
+  QString lcc6 = QStringLiteral("BR123.H56");
+  QString lcc7 = QStringLiteral("BR123.H56 1935");
+  QString lcc8 = QStringLiteral("BR123.H56 B5");
+  QString lcc9 = QStringLiteral("BR123.H8 v.1");
 
   QCOMPARE(comp.compare(lcc1, lcc2) < 0, true);
   QCOMPARE(comp.compare(lcc2, lcc3) < 0, true);
