@@ -33,6 +33,7 @@
 #include "../models/entrygroupmodel.h"
 #include "../models/groupsortmodel.h"
 #include "../models/modeliterator.h"
+#include "../models/entryselectionmodel.h"
 #include "../collections/bookcollection.h"
 #include "../collectionfactory.h"
 #include "../document.h"
@@ -40,6 +41,7 @@
 #include "../images/imagefactory.h"
 
 #include <QTest>
+#include <QSignalSpy>
 
 QTEST_GUILESS_MAIN( TellicoModelTest )
 
@@ -51,7 +53,7 @@ void TellicoModelTest::initTestCase() {
 void TellicoModelTest::testEntryModel() {
   Tellico::Data::CollPtr coll(new Tellico::Data::Collection(true)); // add default fields
   Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll));
-  entry1->setField(QLatin1String("title"), QLatin1String("Star Wars"));
+  entry1->setField(QStringLiteral("title"), QStringLiteral("Star Wars"));
   coll->addEntries(entry1);
 
   Tellico::EntryModel entryModel(this);
@@ -70,7 +72,7 @@ void TellicoModelTest::testEntryModel() {
   entryModel.setEntries(coll->entries());
   QCOMPARE(entryModel.index(0, 0), entryModel.indexFromEntry(entry1));
 
-  Tellico::Data::FieldPtr field1(new Tellico::Data::Field(QLatin1String("test"), QLatin1String("test")));
+  Tellico::Data::FieldPtr field1(new Tellico::Data::Field(QStringLiteral("test"), QStringLiteral("test")));
   coll->addField(field1);
   entryModel.setFields(coll->fields());
 
@@ -78,7 +80,7 @@ void TellicoModelTest::testEntryModel() {
   coll->addEntries(entry2);
   entryModel.addEntries(Tellico::Data::EntryList() << entry2);
 
-  Tellico::Data::FieldPtr field2(new Tellico::Data::Field(QLatin1String("test2"), QLatin1String("test2")));
+  Tellico::Data::FieldPtr field2(new Tellico::Data::Field(QStringLiteral("test2"), QStringLiteral("test2")));
   coll->addField(field2);
   entryModel.addFields(Tellico::Data::FieldList() << field2);
 
@@ -91,8 +93,8 @@ void TellicoModelTest::testEntryModel() {
   QCOMPARE(entryModel.headerData(entryModel.columnCount()-1, Qt::Horizontal, Tellico::FieldPtrRole),
            QVariant::fromValue(field2));
 
-  Tellico::FilterRule* rule1 = new Tellico::FilterRule(QLatin1String("title"),
-                                                       QLatin1String("Star Wars"),
+  Tellico::FilterRule* rule1 = new Tellico::FilterRule(QStringLiteral("title"),
+                                                       QStringLiteral("Star Wars"),
                                                        Tellico::FilterRule::FuncEquals);
   Tellico::FilterPtr filter(new Tellico::Filter(Tellico::Filter::MatchAny));
   filter->append(rule1);
@@ -104,7 +106,7 @@ void TellicoModelTest::testEntryModel() {
   entryModel.setEntries(coll->entries());
   QCOMPARE(entryModel.index(0, 0), entryModel.indexFromEntry(entry1));
 
-  Tellico::Data::FieldPtr field3(new Tellico::Data::Field(QLatin1String("test"), QLatin1String("test-new")));
+  Tellico::Data::FieldPtr field3(new Tellico::Data::Field(QStringLiteral("test"), QStringLiteral("test-new")));
   coll->modifyField(field3);
   QCOMPARE(coll->fields().count(), entryModel.columnCount(QModelIndex()));
   entryModel.modifyField(field2, field3);
@@ -128,8 +130,8 @@ void TellicoModelTest::testFilterModel() {
   Tellico::FilterModel filterModel(this);
   ModelTest test1(&filterModel);
 
-  Tellico::FilterRule* rule1 = new Tellico::FilterRule(QLatin1String("title"),
-                                                       QLatin1String("Star Wars"),
+  Tellico::FilterRule* rule1 = new Tellico::FilterRule(QStringLiteral("title"),
+                                                       QStringLiteral("Star Wars"),
                                                        Tellico::FilterRule::FuncEquals);
   Tellico::FilterPtr filter(new Tellico::Filter(Tellico::Filter::MatchAny));
   filter->append(rule1);
@@ -137,7 +139,7 @@ void TellicoModelTest::testFilterModel() {
 
   Tellico::Data::CollPtr c = Tellico::Data::Document::self()->collection();
   Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(c));
-  entry1->setField(QLatin1String("title"), QLatin1String("Star Wars"));
+  entry1->setField(QStringLiteral("title"), QStringLiteral("Star Wars"));
   c->addEntries(entry1);
 
   filterModel.clear();
@@ -153,8 +155,8 @@ void TellicoModelTest::testFilterModel() {
 void TellicoModelTest::testGroupModel() {
   Tellico::Data::CollPtr coll(new Tellico::Data::BookCollection(true)); // add default fields
   Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll));
-  entry1->setField(QLatin1String("title"), QLatin1String("Star Wars"));
-  entry1->setField(QLatin1String("author"), QLatin1String("George Lucas"));
+  entry1->setField(QStringLiteral("title"), QStringLiteral("Star Wars"));
+  entry1->setField(QStringLiteral("author"), QStringLiteral("George Lucas"));
   coll->addEntries(entry1);
 
   Tellico::EntryGroupModel groupModel(this);
@@ -165,7 +167,7 @@ void TellicoModelTest::testGroupModel() {
 
   sortModel.setSourceModel(&groupModel);
 
-  Tellico::Data::EntryGroupDict* dict = coll->entryGroupDictByName(QLatin1String("author"));
+  Tellico::Data::EntryGroupDict* dict = coll->entryGroupDictByName(QStringLiteral("author"));
   groupModel.addGroups(dict->values(), QString());
   QCOMPARE(sortModel.rowCount(), 1);
 
@@ -173,9 +175,65 @@ void TellicoModelTest::testGroupModel() {
     QVERIFY(gIt.isValid());
     Tellico::Data::EntryGroup* group = gIt.group();
     QVERIFY(group);
-    QCOMPARE(group->groupName(), QLatin1String("Lucas, George"));
-    QCOMPARE(group->fieldName(), QLatin1String("author"));
+    QCOMPARE(group->groupName(), QStringLiteral("Lucas, George"));
+    QCOMPARE(group->fieldName(), QStringLiteral("author"));
     QCOMPARE(group->size(), 1);
     QVERIFY(!group->hasEmptyGroupName());
   }
 }
+
+void TellicoModelTest::testSelectionModel() {
+  qRegisterMetaType<Tellico::Data::EntryList>("Tellico::Data::EntryList");
+  // this mimics the model dependencies used in mainwindow.cpp
+  Tellico::EntryModel entryModel(this);
+  ModelTest test1(&entryModel);
+  Tellico::EntryIconModel iconModel(this);
+  ModelTest test2(&iconModel);
+  iconModel.setSourceModel(&entryModel);
+
+  QItemSelectionModel selModel(&entryModel, this);
+  Tellico::EntrySelectionModel proxySelect(&iconModel, &selModel, this);
+
+//  connect(proxySelect, SIGNAL(entriesSelected(Tellico::Data::EntryList)),
+  Tellico::Data::CollPtr coll(new Tellico::Data::Collection(true)); // add default fields
+  Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll));
+  entry1->setField(QStringLiteral("title"), QStringLiteral("test1"));
+  coll->addEntries(entry1);
+
+  entryModel.setFields(coll->fields());
+  entryModel.setEntries(coll->entries());
+
+  QSignalSpy entriesSelectedSpy(&proxySelect, SIGNAL(entriesSelected(Tellico::Data::EntryList)));
+  selModel.select(entryModel.index(0,0), QItemSelectionModel::Select);
+  QCOMPARE(entriesSelectedSpy.count(), 1);
+
+  Tellico::Data::EntryList entries = proxySelect.selectedEntries();
+  QCOMPARE(entries.count(), 1);
+  QCOMPARE(entries.at(0)->title(), QStringLiteral("test1"));
+
+  Tellico::Data::EntryPtr entry2(new Tellico::Data::Entry(coll));
+  entry2->setField(QStringLiteral("title"), QStringLiteral("test2"));
+  coll->addEntries(entry2);
+  entryModel.addEntries(Tellico::Data::EntryList() << entry2);
+
+  entries = proxySelect.selectedEntries();
+  QCOMPARE(entries.count(), 1);
+  QCOMPARE(entries.at(0)->title(), QStringLiteral("test1"));
+
+  selModel.select(entryModel.index(1,0), QItemSelectionModel::Select);
+  entries = proxySelect.selectedEntries();
+  QCOMPARE(entries.count(), 2);
+  QCOMPARE(entries.at(0)->title(), QStringLiteral("test1"));
+  QCOMPARE(entries.at(1)->title(), QStringLiteral("test2"));
+
+  selModel.select(entryModel.index(0,0), QItemSelectionModel::Toggle);
+  entries = proxySelect.selectedEntries();
+  QCOMPARE(entries.count(), 1);
+  QCOMPARE(entries.at(0)->title(), QStringLiteral("test2"));
+
+  entryModel.clear();
+  // now there should be no selection since EntryModel::clear calls modelReset()
+  // and the proxy selection is connected to that signal
+  entries = proxySelect.selectedEntries();
+  QCOMPARE(entries.count(), 0);
+}
